summaryrefslogtreecommitdiff
path: root/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
diff options
context:
space:
mode:
authorPaul Duffin <paulduffin@google.com>2017-07-28 16:12:47 +0100
committerPaul Duffin <paulduffin@google.com>2017-08-17 15:05:03 +0100
commit26ddc14ad5a88e8238b3a8450aeb35cc6e6a55ac (patch)
treef034e0496e8d34a227ae12b88cb42627ff247d3a /libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
parent9313c2ce2fb61213e66adcf8ab4893a5d9c48da1 (diff)
downloadlibphonenumber-26ddc14ad5a88e8238b3a8450aeb35cc6e6a55ac.tar.gz
Upgrade to 8.7.1
Created using ./update-from-external.sh 8.7.1 m -j32 droid adb reboot bootloader fastboot flashall -w m -j32 cts cts-tradefed run cts -m CtsTelephonyTestCases -t android.telephony.cts.PhoneNumberUtilsTest m -j32 libphonenumber-test vogar dx vogar --timeout 0 \ --classpath ${ANDROID_BUILD_TOP}/out/target/common/obj/JAVA_LIBRARIES/libphonenumber-test_intermediates/classes.jack \ com.google.i18n.phonenumbers Bug: 36705773 Test: as above Change-Id: I07781a60d9052347968ea734226e43a5dac5f837
Diffstat (limited to 'libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java')
-rw-r--r--libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java b/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
index cf94bdb2..cdbd72d1 100644
--- a/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
+++ b/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
@@ -26,9 +26,9 @@ import java.util.Set;
public class AlternateFormatsCountryCodeSet {
// A set of all country codes for which data is available.
static Set<Integer> getCountryCodeSet() {
// The capacity is set to 60 as there are 45 different entries,
// and this offers a load factor of roughly 0.75.
- Set<Integer> countryCodeSet = new HashSet<Integer>(60);
+ Set<Integer> countryCodeSet = new HashSet<Integer>(62);
countryCodeSet.add(7);
countryCodeSet.add(27);
@@ -47,6 +47,7 @@ public class AlternateFormatsCountryCodeSet {
countryCodeSet.add(61);
countryCodeSet.add(62);
countryCodeSet.add(63);
+ countryCodeSet.add(64);
countryCodeSet.add(66);
countryCodeSet.add(81);
countryCodeSet.add(84);
@@ -72,6 +73,7 @@ public class AlternateFormatsCountryCodeSet {
countryCodeSet.add(676);
countryCodeSet.add(679);
countryCodeSet.add(855);
+ countryCodeSet.add(856);
countryCodeSet.add(971);
countryCodeSet.add(972);
countryCodeSet.add(995);
@@ -26,9 +26,9 @@ import java.util.Set;
// A set of all country codes for which data is available.
static Set<Integer> getCountryCodeSet() {
- // The capacity is set to 60 as there are 45 different entries,
+ // The capacity is set to 62 as there are 47 different entries,
// and this offers a load factor of roughly 0.75.